@@ -7,13 +7,21 @@ CCML_DICTIONARY = {
         "domain": "amazon:domain",
         "effect": "amazon:effect",
         "emotion": "amazon:emotion",
-    },
-    "google": {"mark": None, "media": None, "parallel": "par", "sequential": "seq",},
-    "common": {
         "speak": None,
+        "audio": None,
+    },
+    "google": {
+        "mark": None,
+        "media": None,
+        "parallel": "par",
+        "sequential": "seq",
+        "speak": None,
+        "audio": None,
+    },
+    "twilio": {"part-of-speech": "w", "language": "lang", "phoneme": None,},
+    "common": {
         "break": None,
         "say-as": None,
-        "audio": None,
         "p": None,
         "s": None,
         "prosody": None,
